(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     27447,       1103]*)
(*NotebookOutlinePosition[     69192,       2592]*)
(*  CellTagsIndexPosition[     68958,       2581]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[ValueBox["FileName"]], "Title",
  CounterAssignments->{{"Title", 35}, {"SubTitle", 0}, {"SubSubTitle", 0}, {
      "Section", 0}, {"SubSection", 0}, {"SubSubSection", 0}, {
      "NumberedEquation", 0}, {"NumberedFigure", 0}, {"NumberedTable", 0}}],

Cell[TextData[
"Who asks:\t  7.  3.2006\tDr. Norbert S\[UDoubleDot]dland\nHandling:\t  7.  \
3.2006 \[Dash] 24.  3.2006\tDr. Norbert S\[UDoubleDot]dland\nLast \
Calculation:\t24.  3.2006\tDr. Norbert S\[UDoubleDot]dland"], "Subsubtitle",
  TextAlignment->Left],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Question"
}], "Section"],

Cell[TextData[{
  "Are there sensible alternatives to the ",
  StyleBox["thermodynamic temperature",
    FontSlant->"Italic"],
  "?"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Answer"
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Preparation"
}], "Subsection"],

Cell["The following replacing rule is helpful:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntegralCondition = {If[a_, b_, _] \[RuleDelayed] \((Print[a]; b)\)}\)],
   "Input"],

Cell[BoxData[
    \({If[a_, b_, _] \[RuleDelayed] \((Print[a]; b)\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Formula of Textbook"
}], "Subsection"],

Cell[TextData[{
  "The following formula (see ",
  ButtonBox["[HMS2004]",
    ButtonData:>"[HMS2004]",
    ButtonStyle->"Hyperlink"],
  ", formula (3-76), page 174) yields:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CarnotProcess
       = {\[Eta]\_\(th, C\) \[Rule] \(T\_2 - T\_1\)\/T\_2} // Simplify\)], 
  "Input"],

Cell[BoxData[
    \({\[Eta]\_\(th, C\) \[Rule] 1 - T\_1\/T\_2}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Actual Efficiency"
}], "Subsection"],

Cell[TextData[{
  "The efficiency ",
  StyleBox["always",
    FontSlant->"Italic"],
  " is defined in technical physics the following:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Efficiency
       = {\[Eta] \[Rule] ResultingPower\/InvestingPower} /. {
          ResultingPower \[Rule] Abs[WorkingEnergy]\/SpaceOfTime, 
          InvestingPower \[Rule] HeatSupply\/SpaceOfTime}\)], "Input"],

Cell[BoxData[
    \({\[Eta] \[Rule] Abs[WorkingEnergy]\/HeatSupply}\)], "Output"]
}, Open  ]],

Cell["\<\
Thus for a circular process it is possible to consider the involved energies, \
also if this process would need endless time like the Carnot process.\
\>", "Text"],

Cell["\<\
Since for the efficiency of the Carnot process is divided number zero by \
number zero, this kind of consideration sometimes is not sufficient for the \
measuring purpose.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Historical Context"
}], "Subsection"],

Cell[TextData[{
  "The definition of absolute (thermodynamic) temperature by the efficiency \
of the Carnot process has already been legal before the end of world war II. \
(see ",
  ButtonBox["[BS1945]",
    ButtonData:>"[BS1945]",
    ButtonStyle->"Hyperlink"],
  ", volume ",
  StyleBox["1",
    FontWeight->"Bold"],
  ", section 103, page 536). In 1954 (see ",
  ButtonBox["[dtv1969]",
    ButtonData:>"[dtv1969]",
    ButtonStyle->"Hyperlink"],
  ", volume ",
  StyleBox["9",
    FontWeight->"Bold"],
  ", keyword ",
  StyleBox["Temperaturskala",
    FontSlant->"Italic"],
  " (i.e. ",
  StyleBox["temperature scale",
    FontSlant->"Italic"],
  "), page 92) the 10th General Conference for Measurement and Weight decided \
due to recommendation of the Comit\[EAcute] Consultatif de \
Thermom\[EAcute]trie, that the thermodynamic temperature scale is defined by \
use of the triple point of water being a fixed point. This is the actual \
state of the art (see ",
  ButtonBox["[HMS2004]",
    ButtonData:>"[HMS2004]",
    ButtonStyle->"Hyperlink"],
  ", table 1-2, page 7)."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Hurdle to Insight"
}], "Subsection"],

Cell[TextData[{
  "The efficiency of the Carnot process is valid also for gases that own an \
unknown thermal capacity ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\(m, V\)[T]\)]],
  ", because both the heat supply ",
  Cell[BoxData[
      \(TraditionalForm\`\(-Q\)\)]],
  ", and the heat increase ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  ", occur as an integral of this heat capacity:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integral
       = {Q \[Rule] 
          \[Nu] \(\[Integral]\_T\_1\%T\_2 C\_\(m, V\)[T] \[DifferentialD]T\)}
        \)], "Input"],

Cell[BoxData[
    \({Q \[Rule] 
        \[Nu]\ \(\[Integral]\_T\_1\%T\_2 C\_\(m, V\)[T] \[DifferentialD]T\)}
      \)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In the balance both of these integrals add to number zero, thus the \
efficiency of the Carnot process turns out to be independent of the heat \
capacity ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\(m, V\)[T]\)]],
  " of the gas being in use."
}], "Text"],

Cell[TextData[{
  "Not all textbooks (e.g. ",
  ButtonBox["[BS1945]",
    ButtonData:>"[BS1945]",
    ButtonStyle->"Hyperlink"],
  ", volume ",
  StyleBox["I",
    FontWeight->"Bold"],
  ", section 102, pages 528-529) use the heat integral in the general form, \
which can cause a hurdle to insight of the universal applicability of the ",
  StyleBox["themodynamic temperature",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Boltzmann's Alternative?"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Idea"
}], "Subsubsection"],

Cell[TextData[{
  "Temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " is an ",
  StyleBox["intensive",
    FontSlant->"Italic"],
  " quantity, while the internal energy ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  " is an ",
  StyleBox["extensive",
    FontSlant->"Italic"],
  " quantity. Thus is seems to be sensible to discuss the square velocity \
momentum of the distribution function to be proportional to temperature. This \
idea corresponds to the considerations by James Clerk Maxwell and Ludwig \
Boltzmann (see ",
  ButtonBox["[HMS2004]",
    ButtonData:>"[HMS2004]",
    ButtonStyle->"Hyperlink"],
  ", formulae (3-26) to (3-28), page 153):"
}], "Text"],

Cell[BoxData[
    \(U \[Equal] N\ \(E\_kin\)\&_ \[Equal] N \( 1\/2\) m\ \(v\^2\)\&_ 
      \[Equal] N \( 3\/2\) \(k\_B\) T\)], "NumberedEquation",
  CellFrame->True,
  CellTags->"Gaskinetik"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Historical Trial"
}], "Subsubsection"],

Cell[TextData[{
  "An intensive quantity results by division of the extensive mean energy ",
  Cell[BoxData[
      \(TraditionalForm\`\(E\_kin\)\&_\)]],
  " by the extensive mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ". This second momentum of the velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " has historically been classified by Boltzmann to be the kinetic \
temperature."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Confusion with Entropy?"
}], "Subsubsection"],

Cell[TextData[{
  "Due to an elaboration by Albert Einstein the second momentum of a \
distribution rather is to be discussed as a measure for disorder. A more \
detailed consideration also turns out, that the Gaussian variance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  " is a very good measure for disorder and thus can loosen the quantity \
entropy ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The unit of entropy so far has been ",
  Cell[BoxData[
      \(TraditionalForm\`\([J\/K]\)\)]],
  ", this also is the unit of Boltzmann's constant."
}], "Text"],

Cell["\<\
Now there results the question, which unit should have a mechanical \
equivalent for temperature.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". General Variance"
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["Variance",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  " is defined to be the centered second momentum of a normalized \
distribution function and can be presented by the momenta of the same (see ",
  ButtonBox["[BrS1987]",
    ButtonData:>"[BrS1987]",
    ButtonStyle->"Hyperlink"],
  ", section 5.1.3., page 665-668):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Variance[General] = {
        \[Sigma]\^2 \[Rule] 
          Momentum[f[v], 2]\/Momentum[f[v], 0] - 
            \((Momentum[f[v], 1]\/Momentum[f[v], 0])\)\^2}\)], "Input"],

Cell[BoxData[
    \({\[Sigma]\^2 \[Rule] 
        \(-\(Momentum[f[v], 1]\^2\/Momentum[f[v], 0]\^2\)\) + 
          Momentum[f[v], 2]\/Momentum[f[v], 0]}\)], "Output"]
}, Open  ]],

Cell["\<\
Since the velocity distribution function also for Maxwell is valid in three \
dimensions, the following result is yielded by a threefold integral being the \
second momentum presented in sphere coordinates:\
\>", "Text"],

Cell[BoxData[
    \(Momentum[f_, m_?OddQ] := 0\)], "Input"],

Cell[BoxData[
    \(Momentum[f_, m_?EvenQ] := 
      4  \[Pi] \(\[Integral]\_0\%\[Infinity] f\ \(v\^\(2 + m\)\) 
            \[DifferentialD]v\)\)], "Input"],

Cell[TextData[{
  "Here, this yields the following ",
  StyleBox["variance",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Variance[General]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(\[Sigma]\^2\), "\[Rule]", 
        FractionBox[
          RowBox[{
            SubsuperscriptBox["\[Integral]", "0", 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]]], 
            \(\(v\^4\ f[v]\) \[DifferentialD]v\)}], 
          RowBox[{
            SubsuperscriptBox["\[Integral]", "0", 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]]], 
            \(\(v\^2\ f[v]\) \[DifferentialD]v\)}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "In this case, ",
  StyleBox["variance",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  " is identical to the normalized ",
  StyleBox["second momentum",
    FontSlant->"Italic"],
  ", since kinetic gas theory deals with a non-moving substance by ",
  Cell[BoxData[
      \(TraditionalForm\`v\&_ \[Equal] 0\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Concrete Variances"
}], "Subsubsection"],

Cell[TextData[{
  "The distribution function ",
  Cell[BoxData[
      \(TraditionalForm\`f[v]\)]],
  " in the easiest case is ",
  StyleBox["Boltzmann's factor",
    FontSlant->"Italic"],
  ", or respectively ",
  StyleBox["Maxwell's velocity distribution",
    FontSlant->"Italic"],
  " (see ",
  ButtonBox["[HMS2004]",
    ButtonData:>"[HMS2004]",
    ButtonStyle->"Hyperlink"],
  ", Formulae (3-31) and (3-34), page 154 and 155):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BoltzmannsFactor
       = {f[v] \[Rule] Exp[\(-\(\(m\ v\^2\)\/\(2  k\_B\ T\)\)\)]}\)], "Input"],

Cell[BoxData[
    \({f[v] \[Rule] E\^\(-\(\(m\ v\^2\)\/\(2\ T\ k\_B\)\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MaxwellsDistribution
       = {f[v] \[Rule] 
              Exp[\(-\(\(m\ v\^2\)\/\(2  k\_B\ T\)\)\)]\/Momentum[
                  Exp[\(-\(\(m\ v\^2\)\/\(2  k\_B\ T\)\)\)], 0]} /. 
          IntegralCondition // PowerExpand\)], "Input"],

Cell[BoxData[
    \(Re[m\/\(T\ k\_B\)] > 0\)], "Print"],

Cell[BoxData[
    \({f[v] \[Rule] 
        \(E\^\(-\(\(m\ v\^2\)\/\(2\ T\ k\_B\)\)\)\ m\^\(3/2\)\)\/\(2\ \@2\ 
            \[Pi]\^\(3/2\)\ T\^\(3/2\)\ k\_B\%\(3/2\)\)}\)], "Output"]
}, Open  ]],

Cell["In both cases variance yields to be:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Variance[Boltzmann] = 
      \(Variance[General] /. BoltzmannsFactor\) /. IntegralCondition\)], 
  "Input"],

Cell[BoxData[
    \(Re[m\/\(T\ k\_B\)] > 0\)], "Print"],

Cell[BoxData[
    \(Re[m\/\(T\ k\_B\)] > 0\)], "Print"],

Cell[BoxData[
    \({\[Sigma]\^2 \[Rule] \(3\ T\ k\_B\)\/m}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Variance[Maxwell] = 
      \(Variance[General] /. MaxwellsDistribution\) /. IntegralCondition\)], 
  "Input"],

Cell[BoxData[
    \(Re[m\/\(T\ k\_B\)] > 0\)], "Print"],

Cell[BoxData[
    \(Re[m\/\(T\ k\_B\)] > 0\)], "Print"],

Cell[BoxData[
    \({\[Sigma]\^2 \[Rule] \(3\ T\ k\_B\)\/m}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Comparison = Variance[Boltzmann] == Variance[Maxwell]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This confirms that ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\^2\)\&_\)]],
  " in equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Gaskinetik"],
  ") is variance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  " being discussed here, and thus it's ",
  StyleBox["not",
    FontSlant->"Italic"],
  " the absolute temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Mechanical Temperature Equivalent?"
}], "Subsubsection"],

Cell[TextData[{
  "There should result a ",
  StyleBox["mechanical temperature equivalent\[LongDash]",
    FontSlant->"Italic"],
  "here discussed by the example of the idealized helium, or respectively \
hydrogen, thermometer (see ",
  ButtonBox["[HMS2004]",
    ButtonData:>"[HMS2004]",
    ButtonStyle->"Hyperlink"],
  ", formulae (3-27) and (3-28), page 153):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Variance[GasKinetics] = 
      Solve[\(M\/2\) \(v\^2\)\&_ == \(f\/2\) \(R\_m\) T, \(v\^2\)\&_] // 
        Flatten\), 
    \(Variance[Helium] = 
      \(% /. {M \[Rule] 4.0026 "\<g\>"\/"\<mol\>", f \[Rule] 3, 
            R\_m \[Rule] 8.3145 "\<J\>"\/\("\<mol\>" "\<K\>"\), 
            T \[Rule] 1 "\<K\>"}\) /. {"\<g\>" \[Rule] "\<kg\>"\/1000, 
          "\<J\>" \[Rule] \("\<kg\>" "\<m\>"\^2\)\/"\<s\>"\^2}\), 
    \(Variance[Hydrogen] = 
      \(%% /. {M \[Rule] 2*1.008 "\<g\>"\/"\<mol\>", f \[Rule] 3, 
            R\_m \[Rule] 8.3145 "\<J\>"\/\("\<mol\>" "\<K\>"\), 
            T \[Rule] 1 "\<K\>"}\) /. {"\<g\>" \[Rule] "\<kg\>"\/1000, 
          "\<J\>" \[Rule] \("\<kg\>" "\<m\>"\^2\)\/"\<s\>"\^2}\)}], "Input"],

Cell[BoxData[
    \({\(v\^2\)\&_ \[Rule] \(f\ T\ R\_m\)\/M}\)], "Output"],

Cell[BoxData[
    \({\(v\^2\)\&_ \[Rule] \(6231.82431419577209`\ "m"\^2\)\/"s"\^2}\)], 
  "Output"],

Cell[BoxData[
    \({\(v\^2\)\&_ \[Rule] \(12372.7678571428567`\ "m"\^2\)\/"s"\^2}\)], 
  "Output"]
}, Open  ]],

Cell[TextData[{
  "This calculation trial clearly shows that variance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  " is dependent from the mass of the gas particles being in use and thus ",
  StyleBox["cannot",
    FontSlant->"Italic"],
  " be interpreted to be a generalized ",
  StyleBox["temperature",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  "."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Universal Gas Constant"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Molar Consideration"
}], "Subsubsection"],

Cell[TextData[{
  "Equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Gaskinetik"],
  ") can further be written differently, i.e. for the ",
  StyleBox["molar",
    FontSlant->"Italic"],
  " energy:"
}], "Text"],

Cell[BoxData[
    \(U \[Equal] N\ \(E\_kin\)\&_ \[Equal] \(1\/2\) \[Nu]\ M\ \(v\^2\)\&_ 
      \[Equal] \(3\/2\) \[Nu]\ R\_m\ T\)], "NumberedEquation",
  CellFrame->True,
  CellTags->{"Gaskinetik", "Molare Gaskinetik"}],

Cell[TextData[{
  "Here ",
  Cell[BoxData[
      \(TraditionalForm\`R\_m\)]],
  " is the ",
  StyleBox["universal",
    FontSlant->"Italic"],
  " gas constant, which is valid for ",
  StyleBox["all",
    FontSlant->"Italic"],
  " gases:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GasConstant = {R\_m \[Rule] 8.3145 "\<J\>"\/\("\<mol\>" "\<K\>"\)}\)], 
  "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(R\_m\), "\[Rule]", 
        FractionBox[
          RowBox[{
            StyleBox["8.31450000000000066`",
              StyleBoxAutoDelete->True,
              PrintPrecision->5], " ", \("J"\)}], \("K"\ "mol"\)]}], "}"}]], 
  "Output"]
}, Open  ]],

Cell[TextData[{
  "Variance ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\^2\)\&_\)]],
  " does not change by this consideration at all, but there results an \
amazing simple ",
  StyleBox["mechanical temperature equivalent",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[TextData[{
  "If the internal energy ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  " is divided by the ",
  StyleBox["extensive",
    FontSlant->"Italic"],
  " matter quantum ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\)]],
  ", the result is an ",
  StyleBox["intensive",
    FontSlant->"Italic"],
  " quantity, which is proportional to absolute temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TemperatureEquivalent = 
      Solve[U == \(3\/2\) \[Nu]\ \(R\_m\) T /. {U \[Rule] u\ \[Nu]}, u] // 
        Flatten\)], "Input"],

Cell[BoxData[
    \({u \[Rule] \(3\ T\ R\_m\)\/2}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The unit of this reduced internal energy ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm
      \`\([K\ J\/\(mol\ K\)]\) \[Equal] \([J\/mol]\) \[Equal] 
          \([\(kg\ m\^2\)\/\(mol\ s\^2\)]\) := \([K]\)\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Mechanical Temperature Equivalent"
}], "Subsubsection"],

Cell[TextData[{
  "By this a reduced energy quantum is found that corresponds to the \
temperature difference of ",
  Cell[BoxData[
      \(TraditionalForm\`1  K\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TemperatureEquivalent /. GasConstant\) /. {T \[Rule] 1 "\<K\>"}\)], 
  "Input"],

Cell[BoxData[
    \({u \[Rule] \(12.4717499999999992`\ "J"\)\/"mol"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is the reduced internal energy that is changed by an ",
  StyleBox["ideal",
    FontSlant->"Italic"],
  " gas per each Kelvin."
}], "Text"],

Cell[TextData[{
  "Since ",
  StyleBox["real",
    FontSlant->"Italic"],
  " gases often own more freedom degrees ",
  Cell[BoxData[
      \(TraditionalForm\`f \[GreaterEqual] 3\)]],
  ", it is to be exspected and also to be measured, that the molar heat \
capacity ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\(m, V\)[T]\)]],
  " especially for low temperatures corresponds to the phenomenon ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] f \[LessEqual] 3\)]],
  ". The same is valid for solid bodies, which often enough own ",
  Cell[BoxData[
      \(TraditionalForm\`f \[Equal] 6\)]],
  " \[LongDash]even for solid iodine ",
  Cell[BoxData[
      \(TraditionalForm\`I\_2\)]],
  " can be determinded thereby, that the iodine crystal consists of ",
  Cell[BoxData[
      \(TraditionalForm\`I\_2\)]],
  " molecules."
}], "Text"],

Cell["\<\
Heat capacity of an idealized gas for all temperatures is constant and yields \
to be:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(C\_\(m, V\)[Ideal] = 
      \[PartialD]\_T\(\((\(3\/2\) \[Nu]\ \(R\_m\) T)\)\/\[Nu]\)\), 
    \(% /. GasConstant\)}], "Input"],

Cell[BoxData[
    \(\(3\ R\_m\)\/2\)], "Output"],

Cell[BoxData[
    \(\(12.4717499999999992`\ "J"\)\/\("K"\ "mol"\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Even this is the ",
  StyleBox["mechanical temperature equivalent",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Result"
}], "Subsubsection"],

Cell[TextData[{
  "By this is shown, that there is an ",
  StyleBox["absolute",
    FontSlant->"Italic"],
  " temperature scale, which corresponding to theory can be set over all real \
thermometers. Thus there is a theoretical alternative to the temperature \
definition via the Carnot process."
}], "Text"],

Cell[TextData[{
  "The unit of entropy ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " therefore is ",
  Cell[BoxData[
      \(TraditionalForm
      \`\([J\/K]\) \[Equal] \([J\/\(J\/mol\)]\) \[Equal] \([mol]\)\)]],
  " and becomes even less clearly than before: The permanent increase of \
entropy ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " cannot be determinded by the phenomenon, that the experimental \
construction would increase by matter quantum ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\)]],
  " or mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ". Thus entropy ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " is a quantity with a density (near?) of number zero. This forces the \
supposition, that the quantity ",
  StyleBox["entropy",
    FontSlant->"Italic"],
  " according to Rudolf Clausius might have been a reprint of the heat \
substance ",
  StyleBox["phlogiston ",
    FontSlant->"Italic"],
  "(see ",
  ButtonBox["[HMS2004]",
    ButtonData:>"[HMS2004]",
    ButtonStyle->"Hyperlink"],
  ", section 3.3.2., page 159)."
}], "Text"],

Cell[TextData[{
  "The alternative to the entropy ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " according to Ludwig Boltzmann is the older variance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  " according to Carl Friedrich Gauss:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Variance[Maxwell]\)], "Input"],

Cell[BoxData[
    \({\[Sigma]\^2 \[Rule] \(3\ T\ k\_B\)\/m}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Its unit is ",
  Cell[BoxData[
      \(TraditionalForm
      \`\([\(K\ J\)\/\(kg\ K\)]\) \[Equal] \([m\^2\/s\^2]\)\)]],
  ", i.e. a square of velocity\[LongDash]being obvious."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Protocol"
}], "Section"],

Cell[TextData[{
  "The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version has been:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({$Version, $ReleaseNumber, $LicenseID}\)], "Input"],

Cell[BoxData[
    \({"Microsoft Windows 3.0 (October 6, 1996)", 0, "L4526-3546"}\)], 
  "Output"]
}, Open  ]],

Cell["The calculation time needed:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimeUsed[] "\<s\>"\)], "Input"],

Cell[BoxData[
    \(4.75999999999999978`\ "s"\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Subtitle"],

Cell[TextData[{
  "[BrS1987]\nBronstein I. N., Semendjajew K. A., ",
  StyleBox["Taschenbuch der Mathematik",
    FontSlant->"Italic"],
  ", common edition by Nauka publishers, Moskow and BSB B. G. Teubner \
Verlagsgesellschaft Leipzig, 23rd edition, (1987)"
}], "Text",
  CellTags->"[BrS1987]"],

Cell[TextData[{
  "[BS1945]\nBergmann L., Schaefer Cl. ",
  StyleBox["Lehrbuch der Experimentalphysik",
    FontSlant->"Italic"],
  ", volume ",
  StyleBox["I Mechnik, Akustik, W\[ADoubleDot]rme",
    FontWeight->"Bold"],
  ", Walter de Gruyter, Berlin, 2nd and 3rd edition, (1945)"
}], "Text",
  CellTags->"[BS1945]"],

Cell[TextData[{
  "[dtv1969]\n",
  StyleBox["dtv-Lexikon der Physik",
    FontSlant->"Italic"],
  ", ",
  StyleBox["10",
    FontWeight->"Bold"],
  " volumes, Deutscher Taschenbuch Verlag M\[UDoubleDot]nchen, (1969)"
}], "Text",
  CellTags->"[dtv1969]"],

Cell[TextData[{
  "[HMS2004]\nHering E., Martin R., Stohrer M. ",
  StyleBox["Physik f\[UDoubleDot]r Ingenieure",
    FontSlant->"Italic"],
  ", Springer-Verlag Berlin etc., 9th edition, (2004)"
}], "Text",
  CellTags->"[HMS2004]"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
WindowSize->{784, 537},
WindowMargins->{{-4, Automatic}, {-4, Automatic}},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Cell[ 
        TextData[ "\[Copyright] Norbert S\[UDoubleDot]dland"], "Header"], 
      Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Cell[ 
        TextData[ "\[Copyright] Norbert S\[UDoubleDot]dland"], "Header"], 
      Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.996109],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44,
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20,
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36,
    FontColor->RGBColor[0.996109, 0, 0]],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14,
    FontColor->RGBColor[0.996109, 0, 0]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0.8, 0.300008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24,
    FontColor->RGBColor[0, 0.8, 0.300008]],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0.8, 0.300008]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Equation", 0}, {"Figure", 0}, {"Table", 0}, {
        "Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0.500008, 0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24,
    FontColor->RGBColor[0, 0.500008, 0]],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0.500008, 0]],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.500008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0.500008, 0, 0.500008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18,
    FontColor->RGBColor[0.500008, 0, 0.500008]],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10,
    FontColor->RGBColor[0.500008, 0, 0.500008]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    TextJustification->1,
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    TextJustification->1,
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    FontSize->7]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Output",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Printout"],
    CellFrame->True,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->GrayLevel[0.8]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}},
    FontSize->16],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    FontSize->11],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Times",
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{Inherited, 5}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedEquation"], ")"}], FormatType -> TextForm, 
            FontWeight -> "Plain"]}, {None, None}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation1"],
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")  "}], FormatType -> 
            TextForm, FontWeight -> "Plain"]}, {None, None}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["NumberedEquation1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedEquation1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedEquation1", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Abbildung ", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedFigure", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure1"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Abbildung ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedFigure1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedFigure1", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Tabelle ", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedTable", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedTable", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable1"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Tabelle ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedTable1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedTable1", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    FormatType->InputForm,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0],
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{0, 0}, {6, 6}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    ZeroWidthTimes->True,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{0, 0}, {6, 6}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    ShowCellBracket->False,
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    TextAlignment->Center,
    FormatType->InputForm,
    ScriptLevel->0,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0],
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->15],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->10.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{0, 0}, {6, 6}},
    FontSize->9.5]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Equation"],
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Equation", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Equation", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Equation", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10,
    FontWeight->"Bold",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->Primary,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    TextAlignment->Left,
    LineSpacing->{1.1, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1.1, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Presentation"],
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Condensed"],
    FontSize->11,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Presentation"],
    FontSize->16,
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Condensed"],
    FontSize->11,
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.8]]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Centered Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredTitle"],
    CellMargins->{{12, 12}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredTitle", "Presentation"],
    CellMargins->{{24, 24}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["CenteredTitle", "Condensed"],
    CellMargins->{{8, 8}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["CenteredTitle", "Printout"],
    CellMargins->{{2, 2}, {15, 30}},
    FontSize->24]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubtitle"],
    CellMargins->{{12, 12}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubtitle", "Presentation"],
    CellMargins->{{24, 24}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["CenteredSubtitle", "Condensed"],
    CellMargins->{{8, 8}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["CenteredSubtitle", "Printout"],
    CellMargins->{{2, 2}, {10, 15}},
    FontSize->18]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsubtitle"],
    CellMargins->{{12, 12}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsubtitle", "Presentation"],
    CellMargins->{{24, 24}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["CenteredSubsubtitle", "Condensed"],
    CellMargins->{{8, 8}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSubsubtitle", "Printout"],
    CellMargins->{{2, 2}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSection"],
    CellMargins->{{12, 12}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSection", "Presentation"],
    CellMargins->{{24, 24}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["CenteredSection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSection", "Printout"],
    CellMargins->{{2, 2}, {7, 22}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsection"],
    CellMargins->{{12, 12}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsection", "Presentation"],
    CellMargins->{{24, 24}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["CenteredSubsection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSubsection", "Printout"],
    CellMargins->{{2, 2}, {7, 22}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsubsection"],
    CellMargins->{{12, 12}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsubsection", "Presentation"],
    CellMargins->{{24, 24}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["CenteredSubsubsection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["CenteredSubsubsection", "Printout"],
    CellMargins->{{2, 2}, {7, 14}},
    FontSize->11]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    CellTags->"NotationPackage"]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Gaskinetik"->{
    Cell[8770, 342, 191, 4, 77, "NumberedEquation",
      CellTags->"Gaskinetik"],
    Cell[18897, 750, 219, 4, 77, "NumberedEquation",
      CellTags->{"Gaskinetik", "Molare Gaskinetik"}]},
  "Molare Gaskinetik"->{
    Cell[18897, 750, 219, 4, 77, "NumberedEquation",
      CellTags->{"Gaskinetik", "Molare Gaskinetik"}]},
  "[BrS1987]"->{
    Cell[26313, 1062, 295, 7, 93, "Text",
      CellTags->"[BrS1987]"]},
  "[BS1945]"->{
    Cell[26611, 1071, 318, 9, 93, "Text",
      CellTags->"[BS1945]"]},
  "[dtv1969]"->{
    Cell[26932, 1082, 253, 9, 69, "Text",
      CellTags->"[dtv1969]"]},
  "[HMS2004]"->{
    Cell[27188, 1093, 231, 6, 93, "Text",
      CellTags->"[HMS2004]"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Gaskinetik", 68251, 2557},
  {"Molare Gaskinetik", 68467, 2562},
  {"[BrS1987]", 68592, 2565},
  {"[BS1945]", 68681, 2568},
  {"[dtv1969]", 68770, 2571},
  {"[HMS2004]", 68860, 2574}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 262, 3, 154, "Title",
  CounterAssignments->{{"Title", 35}, {"SubTitle", 0}, {"SubSubTitle", 0}, {
      "Section", 0}, {"SubSection", 0}, {"SubSubSection", 0}, {
      "NumberedEquation", 0}, {"NumberedFigure", 0}, {"NumberedTable", 0}}],
Cell[1996, 56, 260, 4, 120, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2281, 64, 100, 5, 76, "Section"],
Cell[2384, 71, 144, 5, 45, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2565, 81, 98, 5, 76, "Section"],

Cell[CellGroupData[{
Cell[2688, 90, 141, 7, 68, "Subsection"],
Cell[2832, 99, 56, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[2913, 103, 104, 2, 41, "Input"],
Cell[3020, 107, 82, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3151, 114, 149, 7, 68, "Subsection"],
Cell[3303, 123, 185, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[3513, 133, 120, 3, 70, "Input"],
Cell[3636, 138, 76, 1, 63, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3761, 145, 147, 7, 68, "Subsection"],
Cell[3911, 154, 147, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[4083, 163, 230, 4, 131, "Input"],
Cell[4316, 169, 81, 1, 64, "Output"]
}, Open  ]],
Cell[4412, 173, 173, 3, 69, "Text"],
Cell[4588, 178, 195, 4, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4820, 187, 148, 7, 68, "Subsection"],
Cell[4971, 196, 1091, 32, 189, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6099, 233, 147, 7, 68, "Subsection"],
Cell[6249, 242, 412, 12, 93, "Text"],

Cell[CellGroupData[{
Cell[6686, 258, 149, 4, 67, "Input"],
Cell[6838, 264, 129, 3, 67, "Output"]
}, Open  ]],
Cell[6982, 270, 278, 7, 69, "Text"],
Cell[7263, 279, 422, 13, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7722, 297, 154, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[7901, 308, 175, 9, 61, "Subsubsection"],
Cell[8079, 319, 688, 21, 117, "Text"],
Cell[8770, 342, 191, 4, 77, "NumberedEquation",
  CellTags->"Gaskinetik"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8998, 351, 187, 9, 61, "Subsubsection"],
Cell[9188, 362, 418, 12, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9643, 379, 194, 9, 61, "Subsubsection"],
Cell[9840, 390, 440, 11, 117, "Text"],
Cell[10283, 403, 179, 5, 53, "Text"],
Cell[10465, 410, 121, 3, 45, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10623, 418, 187, 9, 61, "Subsubsection"],
Cell[10813, 429, 409, 12, 93, "Text"],

Cell[CellGroupData[{
Cell[11247, 445, 192, 4, 72, "Input"],
Cell[11442, 451, 166, 3, 68, "Output"]
}, Open  ]],
Cell[11623, 457, 230, 4, 93, "Text"],
Cell[11856, 463, 59, 1, 41, "Input"],
Cell[11918, 466, 157, 3, 62, "Input"],
Cell[12078, 471, 185, 8, 45, "Text"],

Cell[CellGroupData[{
Cell[12288, 483, 50, 1, 41, "Input"],
Cell[12341, 486, 537, 13, 77, "Output"]
}, Open  ]],
Cell[12893, 502, 393, 14, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13323, 521, 189, 9, 61, "Subsubsection"],
Cell[13515, 532, 445, 15, 69, "Text"],

Cell[CellGroupData[{
Cell[13985, 551, 115, 2, 74, "Input"],
Cell[14103, 555, 88, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14228, 561, 256, 5, 151, "Input"],
Cell[14487, 568, 55, 1, 53, "Print"],
Cell[14545, 571, 181, 3, 92, "Output"]
}, Open  ]],
Cell[14741, 577, 52, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[14818, 581, 127, 3, 66, "Input"],
Cell[14948, 586, 55, 1, 53, "Print"],
Cell[15006, 589, 55, 1, 53, "Print"],
Cell[15064, 592, 73, 1, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15174, 598, 129, 3, 66, "Input"],
Cell[15306, 603, 55, 1, 53, "Print"],
Cell[15364, 606, 55, 1, 53, "Print"],
Cell[15422, 609, 73, 1, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15532, 615, 86, 1, 41, "Input"],
Cell[15621, 618, 38, 1, 41, "Output"]
}, Open  ]],
Cell[15674, 622, 459, 18, 73, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16170, 645, 205, 9, 61, "Subsubsection"],
Cell[16378, 656, 376, 10, 93, "Text"],

Cell[CellGroupData[{
Cell[16779, 670, 743, 13, 350, "Input"],
Cell[17525, 685, 73, 1, 60, "Output"],
Cell[17601, 688, 99, 2, 64, "Output"],
Cell[17703, 692, 99, 2, 64, "Output"]
}, Open  ]],
Cell[17817, 697, 421, 14, 69, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18287, 717, 152, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[18464, 728, 190, 9, 61, "Subsubsection"],
Cell[18657, 739, 237, 9, 45, "Text"],
Cell[18897, 750, 219, 4, 77, "NumberedEquation",
  CellTags->{"Gaskinetik", "Molare Gaskinetik"}],
Cell[19119, 756, 249, 11, 45, "Text"],

Cell[CellGroupData[{
Cell[19393, 771, 102, 2, 66, "Input"],
Cell[19498, 775, 282, 8, 59, "Output"]
}, Open  ]],
Cell[19795, 786, 271, 9, 73, "Text"],
Cell[20069, 797, 445, 17, 69, "Text"],

Cell[CellGroupData[{
Cell[20539, 818, 149, 3, 66, "Input"],
Cell[20691, 823, 63, 1, 59, "Output"]
}, Open  ]],
Cell[20769, 827, 301, 10, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21107, 842, 204, 9, 61, "Subsubsection"],
Cell[21314, 853, 184, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[21523, 863, 101, 2, 41, "Input"],
Cell[21627, 867, 82, 1, 59, "Output"]
}, Open  ]],
Cell[21724, 871, 163, 5, 45, "Text"],
Cell[21890, 878, 843, 24, 141, "Text"],
Cell[22736, 904, 110, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[22871, 911, 147, 3, 112, "Input"],
Cell[23021, 916, 48, 1, 59, "Output"],
Cell[23072, 919, 79, 1, 59, "Output"]
}, Open  ]],
Cell[23166, 923, 130, 5, 45, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23333, 933, 177, 9, 61, "Subsubsection"],
Cell[23513, 944, 308, 7, 93, "Text"],
Cell[23824, 953, 1093, 35, 182, "Text"],
Cell[24920, 990, 269, 8, 69, "Text"],

Cell[CellGroupData[{
Cell[25214, 1002, 50, 1, 41, "Input"],
Cell[25267, 1005, 73, 1, 60, "Output"]
}, Open  ]],
Cell[25355, 1009, 207, 6, 61, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25623, 1022, 100, 5, 76, "Section"],
Cell[25726, 1029, 112, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[25863, 1038, 71, 1, 41, "Input"],
Cell[25937, 1041, 97, 2, 41, "Output"]
}, Open  ]],
Cell[26049, 1046, 44, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[26118, 1050, 51, 1, 41, "Input"],
Cell[26172, 1053, 59, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26280, 1060, 30, 0, 80, "Subtitle"],
Cell[26313, 1062, 295, 7, 93, "Text",
  CellTags->"[BrS1987]"],
Cell[26611, 1071, 318, 9, 93, "Text",
  CellTags->"[BS1945]"],
Cell[26932, 1082, 253, 9, 69, "Text",
  CellTags->"[dtv1969]"],
Cell[27188, 1093, 231, 6, 93, "Text",
  CellTags->"[HMS2004]"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

